@@ -19,7 +19,7 @@ from griffon.commands.reports import generate_affects_report
 from griffon.output import cprint
 from griffon.services import QueryService, core_queries  # , exp
 
-logger = logging.getLogger("rich")
+logger = logging.getLogger("griffon")
 
 query_service = QueryService()
 
@@ -37,9 +37,14 @@ queries_grp.add_command(generate_affects_for_component_process)
 
 @queries_grp.command(
     name="product-summary",
-    help="Get Product summary.",
+    help="Get Product summaries.",
+)
+@click.argument(
+    "product_stream_name",
+    required=False,
+    type=click.STRING,
+    shell_complete=get_product_stream_names,
 )
-@click.argument("product_stream_name", required=False)
 @click.option(
     "--ofuri",
     "ofuri",
@@ -56,7 +61,7 @@ queries_grp.add_command(generate_affects_for_component_process)
 )
 @click.pass_context
 @progress_bar
-def get_product_query(ctx, product_stream_name, ofuri, strict_name_search):
+def get_product_summary(ctx, product_stream_name, ofuri, strict_name_search):
     """get product stream."""
     if not product_stream_name and not ofuri:
         click.echo(ctx.get_help())
@@ -241,41 +246,52 @@ def get_product_latest_components_query(ctx, product_stream_name, ofuri):
     ctx.invoke(list_components, **cond)
 
 
-@queries_grp.command(
-    name="product-all-components",
-    help="List ALL Components of Product.",
-)
-@click.argument("product_stream_name", required=False, shell_complete=get_product_stream_names)
-@click.pass_context
-@click.option("--ofuri", "ofuri", type=click.STRING, shell_complete=get_product_stream_ofuris)
-def get_product_all_components_query(ctx, product_stream_name, ofuri):
-    """List components of a specific product stream."""
-    if not ofuri and not product_stream_name:
-        click.echo(ctx.get_help())
-        exit(0)
-    cond = {}
-    if ofuri:
-        cond["product_stream_ofuri"] = ofuri
-    if product_stream_name:
-        # lookup ofuri
-        q = query_service.invoke(core_queries.product_stream_summary, ctx.params)
-        ofuri = q[0]["ofuri"]
-        cond["product_stream_ofuri"] = ofuri
-    ctx.invoke(list_components, **cond)
+# TODO- can always use entity commands to achieve this, deactivating for the time being
+# @queries_grp.command(
+#     name="product-all-components",
+#     help="List ALL Components of Product.",
+# )
+# @click.argument("product_stream_name", required=False, shell_complete=get_product_stream_names)
+# @click.pass_context
+# @click.option("--ofuri", "ofuri", type=click.STRING, shell_complete=get_product_stream_ofuris)
+# def get_product_all_components_query(ctx, product_stream_name, ofuri):
+#     """List components of a specific product stream."""
+#     if not ofuri and not product_stream_name:
+#         click.echo(ctx.get_help())
+#         exit(0)
+#     cond = {}
+#     if ofuri:
+#         cond["product_stream_ofuri"] = ofuri
+#     if product_stream_name:
+#         # lookup ofuri
+#         q = query_service.invoke(core_queries.product_stream_summary, ctx.params)
+#         ofuri = q[0]["ofuri"]
+#         cond["product_stream_ofuri"] = ofuri
+#     ctx.invoke(list_components, **cond)
 
 
 @queries_grp.command(
     name="component-manifest",
     help="Get Component manifest.",
 )
+@click.option("--uuid", "Component_uuid")
+@click.option("--purl", help="Component Purl (must be quoted).")
+@click.option(
+    "--spdx-json",
+    "spdx_json_format",
+    is_flag=True,
+    default=False,
+    help="Generate spdx manifest (json).",
+)
 @click.pass_context
-@click.option("--uuid", "component_uuid")
-@click.option("--purl", help="Purl are URI and must be quoted.")
-def retrieve_component_manifest(ctx, component_uuid, purl):
+def retrieve_component_manifest(ctx, component_uuid, purl, spdx_json_format):
     """Retrieve component manifest."""
     if not component_uuid and not purl:
         click.echo(ctx.get_help())
         exit(0)
+    if spdx_json_format:
+        ctx.ensure_object(dict)
+        ctx.obj["FORMAT"] = "json"
     cond = {}
     if component_uuid:
         cond["component_uuid"] = component_uuid
@@ -288,34 +304,34 @@ def retrieve_component_manifest(ctx, component_uuid, purl):
     name="components-affected-by-flaw",
     help="List Components affected by Flaw.",
 )
-@click.option("--cve-id", shell_complete=get_cve_ids)
+@click.argument("cve_id", required=False, type=click.STRING, shell_complete=get_cve_ids)
 @click.option(
     "--affectedness",
-    help="Filter by affect affectedness.",
+    help="Filter by Affect affectedness.",
     type=click.Choice(OSIDBService.get_affect_affectedness()),
 )
 @click.option(
     "--resolution",
     "affect_resolution",
-    help="Filter by affect resolution.",
+    help="Filter by Affect resolution.",
     type=click.Choice(OSIDBService.get_affect_resolution()),
 )
 @click.option(
     "--impact",
     "affect_impact",
-    help="Filter by affect impact.",
+    help="Filter by Affect impact.",
     type=click.Choice(OSIDBService.get_affect_impact()),
 )
 @click.option(
     "--type",
     "component_type",
     type=click.Choice(CorgiService.get_component_types()),
-    help="Filter by component type.",
+    help="Filter by Component type.",
 )
 @click.option(
     "--namespace",
     type=click.Choice(CorgiService.get_component_namespaces()),
-    help="filter by component namespace.",
+    help="filter by Component namespace.",
 )
 @click.pass_context
 @progress_bar
@@ -334,14 +350,14 @@ def components_affected_by_specific_cve_query(
 
 
 @queries_grp.command(
-    name="products-affected-by-cve",
-    help="List Products affected by CVE.",
+    name="products-affected-by-flaw",
+    help="List Products affected by Flaw.",
 )
 @click.option("--cve-id", shell_complete=get_cve_ids)
 @click.pass_context
 @progress_bar
 def product_versions_affected_by_cve_query(ctx, cve_id):
-    """List products affected by a CVE."""
+    """List Products affected by a CVE."""
     if not cve_id:
         click.echo(ctx.get_help())
         exit(0)
@@ -351,54 +367,142 @@ def product_versions_affected_by_cve_query(ctx, cve_id):
     cprint(q, ctx=ctx)
 
 
-@queries_grp.command(name="flaws-component", help="(UNDER DEV) List Flaws affecting a Component.")
+@queries_grp.command(name="component-flaws", help="List Flaws affecting a Component.")
+@click.argument("component_name", required=False)
 @click.option("--purl")
-@click.option("--affectedness")
+@click.option(
+    "--flaw-state",
+    "flaw_state",
+    help="Filter by Flaw state.",
+    type=click.Choice(OSIDBService.get_flaw_states()),
+)
+@click.option(
+    "--flaw-impact",
+    "flaw_impact",
+    help="Filter by Flaw impact.",
+    type=click.Choice(OSIDBService.get_flaw_impacts()),
+)
+@click.option(
+    "--flaw-resolution",
+    "flaw_resolution",
+    help="Filter by Flaw resolution.",
+    type=click.Choice(OSIDBService.get_flaw_resolutions()),
+)
+@click.option(
+    "--affectedness",
+    help="Filter by Affect affectedness.",
+    type=click.Choice(OSIDBService.get_affect_affectedness()),
+)
+@click.option(
+    "--affect-resolution",
+    "affect_resolution",
+    help="Filter by Affect resolution.",
+    type=click.Choice(OSIDBService.get_affect_resolution()),
+)
+@click.option(
+    "--affect-impact",
+    "affect_impact",
+    help="Filter by Affect impact.",
+    type=click.Choice(OSIDBService.get_affect_impact()),
+)
+@click.option(
+    "-s",
+    "strict_name_search",
+    is_flag=True,
+    default=False,
+    help="Strict search, exact match of component name.",
+)
 @click.pass_context
 @progress_bar
-def cves_for_specific_component_query(ctx, purl, affectedness):
-    """List cves of a specific component."""
-    if not purl:
+def cves_for_specific_component_query(
+    ctx,
+    component_name,
+    purl,
+    flaw_state,
+    flaw_impact,
+    flaw_resolution,
+    affectedness,
+    affect_resolution,
+    affect_impact,
+    strict_name_search,
+):
+    """List flaws of a specific component."""
+    if not purl and not component_name:
         click.echo(ctx.get_help())
         exit(0)
+
     q = query_service.invoke(core_queries.cves_for_specific_component_query, ctx.params)
     cprint(q, ctx=ctx)
 
 
 @queries_grp.command(
-    name="flaws-product",
-    help="(UNDER DEV) List Flaws affecting a Product.",
+    name="product-flaws",
+    help="List Flaws affecting a Product.",
 )
-@click.option(
-    "--re-name",
-    "product_version_re_name",
-    help="product_version name (eg. ps_module)",
-    shell_complete=get_product_version_names,
-)
-@click.option(
-    "--name",
+@click.argument(
     "product_version_name",
-    help="product_version name (eg. ps_module)",
+    required=False,
+    type=click.STRING,
     shell_complete=get_product_version_names,
 )
-@click.option("--affectedness", type=click.Choice(OSIDBService.get_affect_affectedness()))
-@click.option("--affect-impact", type=click.Choice(OSIDBService.get_flaw_impacts()))
-@click.option("--affect-resolution", type=click.Choice(OSIDBService.get_affect_resolution()))
-@click.option("--flaw-state", type=click.Choice(OSIDBService.get_flaw_states()))
-@click.option("--flaw-resolution", type=click.Choice(OSIDBService.get_flaw_resolutions()))
+@click.option("--ofuri")
+@click.option(
+    "--flaw-state",
+    "flaw_state",
+    help="Filter by Flaw state.",
+    type=click.Choice(OSIDBService.get_flaw_states()),
+)
+@click.option(
+    "--flaw-impact",
+    "flaw_impact",
+    help="Filter by Flaw impact.",
+    type=click.Choice(OSIDBService.get_flaw_impacts()),
+)
+@click.option(
+    "--flaw-resolution",
+    "flaw_resolution",
+    help="Filter by Flaw resolution.",
+    type=click.Choice(OSIDBService.get_flaw_resolutions()),
+)
+@click.option(
+    "--affectedness",
+    help="Filter by Affect affectedness.",
+    type=click.Choice(OSIDBService.get_affect_affectedness()),
+)
+@click.option(
+    "--affect-resolution",
+    "affect_resolution",
+    help="Filter by Affect resolution.",
+    type=click.Choice(OSIDBService.get_affect_resolution()),
+)
+@click.option(
+    "--affect-impact",
+    "affect_impact",
+    help="Filter by Affect impact.",
+    type=click.Choice(OSIDBService.get_affect_impact()),
+)
+@click.option(
+    "-s",
+    "strict_name_search",
+    is_flag=True,
+    default=False,
+    help="Strict search, exact match of component name.",
+)
 @click.pass_context
 def cves_for_specific_product_query(
     ctx,
-    product_version_re_name,
     product_version_name,
+    ofuri,
+    flaw_state,
+    flaw_impact,
+    flaw_resolution,
     affectedness,
     affect_impact,
     affect_resolution,
-    flaw_state,
-    flaw_resolution,
+    strict_name_search,
 ):
-    """List cves of a specific product."""
-    if not product_version_name:
+    """List flaws of a specific product."""
+    if not product_version_name and not ofuri:
         click.echo(ctx.get_help())
         exit(0)
     q = query_service.invoke(core_queries.cves_for_specific_product_query, ctx.params)
